@@ -5,6 +5,7 @@ from os import environ
 from typing import Callable, Dict, Any
 
 from dataclasses import dataclass
+from deprecation import deprecated
 
 from petisco.event.bus.infrastructure.not_implemented_event_bus import (
     NotImplementedEventBus,
@@ -38,7 +39,7 @@ from petisco.notifier.domain.notifier_message import NotifierMessage
 from petisco.application.config.config import Config
 from petisco.application.singleton import Singleton
 from petisco.application.interface_repository import IRepository
-from petisco.application.interface_service import IService
+from petisco.application.interface_application_service import IService, IAppService
 from petisco.tasks.infrastructure.apscheduler_task_executor import (
     APSchedulerTaskExecutor,
 )
@@ -342,7 +343,7 @@ class Petisco(metaclass=Singleton):
         return services
 
     @staticmethod
-    def get_service(key: str) -> IService:
+    def get_app_service(key: str) -> IAppService:
         services = Petisco.get_instance().services
         if not services:
             raise ValueError(
@@ -355,6 +356,11 @@ class Petisco(metaclass=Singleton):
             )
         return service
 
+    @staticmethod
+    @deprecated("This method is deprecated. Please, use get_app_service")
+    def get_service(key: str) -> IService:
+        return Petisco.get_app_service(key)
+
     @staticmethod
     def get_repository(key: str) -> IRepository:
         repositories = Petisco.get_instance().repositories
@@ -396,12 +402,6 @@ class Petisco(metaclass=Singleton):
     def get_event_bus():
         return Petisco.get_instance().event_bus
 
-    @staticmethod
-    def persistence_mongodb_database():
-        from petisco.persistence.pymongo.pymongo_persistence import PyMongoPersistence
-
-        return PyMongoPersistence().database
-
     @staticmethod
     def persistence_mongodb_client():
         from petisco.persistence.pymongo.pymongo_persistence import PyMongoPersistence
