@@ -7,11 +7,12 @@
 
 from petisco.application.config.config import Config
 from petisco.application.interface_repository import IRepository
-from petisco.application.interface_service import IService
+from petisco.application.interface_application_service import IService, IAppService
 from petisco.application.petisco import Petisco
 from petisco.application.singleton import Singleton
 from petisco.domain.aggregate_roots.aggregate_root import AggregateRoot
 from petisco.domain.aggregate_roots.info_id import InfoId
+from petisco.domain.date_parser import DateParser
 from petisco.domain.errors.empty_value_object_error import EmptyValueObjectError
 from petisco.domain.errors.length_limit_string_value_object_error import (
     ExceedLengthLimitValueObjectError,
@@ -101,7 +102,8 @@ from petisco.webhooks.webhook.domain.webhook_sender import WebhookSender
 
 
 classes = [
-    "IService",
+    "IService",  # deprecated
+    "IAppService",
     "IRepository",
     "UseCase",
     "use_case_handler",
@@ -176,6 +178,7 @@ classes = [
     "NotHasSpecificLengthValueObjectError",
     "Secret",
     "SignatureAlgorithm",
+    "DateParser",
 ]
 
 
@@ -305,11 +308,23 @@ try:
     from petisco.persistence.pymongo.pymongo_persistence_connector import (
         PyMongoPersistenceConnector,
     )
+    from petisco.persistence.pymongo.pymongo_errors import (
+        PyMongoOperationalDatabaseError,
+        PyMongoInvalidDatabaseNameError,
+        PyMongoInvalidCollectionNameError,
+    )
+    from petisco.persistence.pymongo.pymongo_persistence_context import (
+        get_mongo_collection,
+    )
 
     pymongo = [
         "PyMongoPersistence",
         "PyMongoPersistenceConfig",
         "PyMongoPersistenceConnector",
+        "PyMongoInvalidCollectionNameError",
+        "PyMongoInvalidDatabaseNameError",
+        "PyMongoInvalidCollectionNameError",
+        "get_mongo_collection",
     ]
 except (RuntimeError, ImportError):
     pymongo = []
